/**
 * Simple example of basic AC controller
 * This code provide options to control AC mode, temperature, and power, 
 * with default options for swing and fan.
 * 
 * You can call controller as follow:
 * http://xxx.xxx.xxx.xxx/{on|off}?mode={cool|heat}&temp={number}
 * 
 * Exmaple setting ac on COOL and 22C where IP of the controller is 192.168.0.24
 * http://192.168.0.24/on?mode=cool&temp=22
 */
#include <ESP8266WiFi.h>
#include <ESP8266WebServer.h>
#include <Arduino.h>
#include <IRremoteESP8266.h>
#include <IRsend.h>
#include <ir_Fujitsu.h>

// Create web server on port 80
ESP8266WebServer server(80);

// Wifi name and password to connect to
const char* ssid = "";
const char* password =  "";

// ESP8266 GPIO pin to use. Recommended: 4 (D2).
const uint16_t kIrLed = 4;

// Set the GPIO to be used for sending messages.
IRFujitsuAC ac(kIrLed); 
 
void setup() {
 
    // Use for debuging
    Serial.begin(115200);

    // Disable access point mode
    WiFi.mode(WIFI_STA);

    //Connect to the WiFi network
    WiFi.begin(ssid, password);
 
    //Wait for connection
    while (WiFi.status() != WL_CONNECTED) {
        delay(500);
        Serial.println("Waiting to connect...");
    }
 
    //Print the local IP
    Serial.print("IP address: ");
    Serial.println(WiFi.localIP());
 
    //Associate the handler function to the path
    server.on("/on", turnOn); 
    server.on("/off", turnOff);
 
    //Start the server
    server.begin();
    Serial.println("Server listening");

    // Init Fujitsu AC
    ac.begin(); 
    ac.setModel(ARREB1E);
}
 
void loop() {
    //HANDLING OF INCOMING REQUESTS
    server.handleClient();
}

void turnOff() {
    // TURN OFF AC
    ac.setCmd(kFujitsuAcCmdTurnOff);
    ac.send();

    // PRINT TEXT RESPONSE
    server.send(200, "text/plain", "AC OFF");
    Serial.println("AC OFF");
}
 
void turnOn() {
      // SET DEFAULT SWING MODE
      ac.setSwing(kFujitsuAcSwingVert);
      
      // SET MODE - COOL | HEAT
      if (server.hasArg("mode")== false) {
        ac.setMode(kFujitsuAcModeCool);
      } else {
        ac.setMode( server.arg("mode") == "cool" ? kFujitsuAcModeCool : kFujitsuAcModeHeat);
      }
      
      // SET FAN SPEED ON AUTO
      ac.setFanSpeed(kFujitsuAcFanAuto);
      
      // SET TEMP
      if (server.hasArg("temp")== false) {
        ac.setTemp(23);
      } else {
        ac.setTemp(server.arg("temp").toInt());
      }
      ac.setCmd(kFujitsuAcCmdTurnOn);
      ac.send();

      // PRINT TEXT RESPONSE
      server.send(200, "text/plain", "AC ON");
      Serial.println("AC ON");
}
